=======================
Contributing to Mistral
=======================

If you're interested in contributing to the Mistral project,
the following will help get you started.

Contributor License Agreement
=============================

In order to contribute to the Mistral project, you need to have
signed OpenStack's contributor's agreement:

* https://docs.openstack.org/infra/manual/developers.html
* https://wiki.openstack.org/CLA


Project Hosting Details
=======================

* Bug trackers
    * General mistral tracker: https://launchpad.net/mistral

    * Python client tracker: https://launchpad.net/python-mistralclient

* Mailing list (prefix subjects with ``[Mistral]`` for faster responses)
    http://lists.openstack.org/cgi-bin/mailman/listinfo/openstack-dev

* Documentation
    * https://docs.openstack.org/mistral/latest/

* IRC channel
    * #openstack-mistral at FreeNode

    * https://wiki.openstack.org/wiki/Mistral/Meetings_Meetings

* Code Hosting
    * https://github.com/openstack/mistral

    * https://github.com/openstack/python-mistralclient

    * https://github.com/openstack/mistral-dashboard

    * https://github.com/openstack/mistral-lib

    * https://github.com/openstack/mistral-specs

    * https://github.com/openstack/mistral-specs

* Code Review
    * https://review.openstack.org/#/q/mistral

    * https://review.openstack.org/#/q/python-mistralclient

    * https://review.openstack.org/#/q/mistral-dashboard

    * https://review.openstack.org/#/q/mistral-lib

    * https://review.openstack.org/#/q/mistral-extra

    * https://review.openstack.org/#/q/mistral-specs

    * https://docs.openstack.org/infra/manual/developers.html#development-workflow

* Mistral Design Specifications
    * https://specs.openstack.org/openstack/mistral-specs/
